@@ -320,23 +320,26 @@ class Scan:
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
         to_remove = []
         for i in iterator:
-            if self.data['roi1_maxval'][i] > self.pixel_max:
-                to_remove.append(i)
-                continue
-            im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold)
-            if crop_kwargs is None:
-                im.crop(crop_function)
-            else:
-                im.crop(crop_function, **crop_kwargs)
-            if bkg_sub_kwargs is None:
-                im.background_subtraction(bkg_sub_function)
-            else:
-                im.background_subtraction(bkg_sub_function, **bkg_sub_kwargs)
-            self.R[i] = ufloat(im.sum().n, im.sum().s)
-            if im.n_pixel is None:
-                self.n_pixels[i] = None
-            else:
-                self.n_pixels[i] = im.n_pixel.n
+            try:
+                if self.data['roi1_maxval'][i] > self.pixel_max:
+                    to_remove.append(i)
+                    continue
+                im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold)
+                if crop_kwargs is None:
+                    im.crop(crop_function)
+                else:
+                    im.crop(crop_function, **crop_kwargs)
+                if bkg_sub_kwargs is None:
+                    im.background_subtraction(bkg_sub_function)
+                else:
+                    im.background_subtraction(bkg_sub_function, **bkg_sub_kwargs)
+                self.R[i] = ufloat(im.sum().n, im.sum().s)
+                if im.n_pixel is None:
+                    self.n_pixels[i] = None
+                else:
+                    self.n_pixels[i] = im.n_pixel.n
+            except (ValueError, RuntimeError):
+                print('ERROR ON FILE:', self.file_path)
         self.R = np.delete(self.R, to_remove)
         self.theta = np.delete(self.theta, to_remove)
         self.n_pixels = np.delete(self.n_pixels, to_remove)
